==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/inputs/GetGatewayHostnameConfigurationPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin.inputs

import com.pulumi.azurenative.apimanagement.inputs.GetGatewayHostnameConfigurationPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property gatewayId Gateway entity identifier. Must be unique in the current API Management service instance. Must not have value 'managed'
 * @property hcId Gateway hostname configuration identifier. Must be unique in the scope of parent Gateway entity.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property serviceName The name of the API Management service.
 */
public data class GetGatewayHostnameConfigurationPlainArgs(
    public val gatewayId: String,
    public val hcId: String,
    public val resourceGroupName: String,
    public val serviceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.apimanagement.inputs.GetGatewayHostnameConfigurationPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.apimanagement.inputs.GetGatewayHostnameConfigurationPlainArgs =
        com.pulumi.azurenative.apimanagement.inputs.GetGatewayHostnameConfigurationPlainArgs.builder()
            .gatewayId(gatewayId.let({ args0 -> args0 }))
            .hcId(hcId.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetGatewayHostnameConfigurationPlainArgs].
 */
@PulumiTagMarker
public class GetGatewayHostnameConfigurationPlainArgsBuilder internal constructor() {
    private var gatewayId: String? = null

    private var hcId: String? = null

    private var resourceGroupName: String? = null

    private var serviceName: String? = null

    /**
     * @param value Gateway entity identifier. Must be unique in the current API Management service instance. Must not have value 'managed'
     */
    @JvmName("hyjqistasuqalkuj")
    public suspend fun gatewayId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.gatewayId = mapped
    }

    /**
     * @param value Gateway hostname configuration identifier. Must be unique in the scope of parent Gateway entity.
     */
    @JvmName("jopvvgfacswqcdxx")
    public suspend fun hcId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.hcId = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("uygjvsafsqnivdoq")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the API Management service.
     */
    @JvmName("jpgauwcohmufiowd")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): GetGatewayHostnameConfigurationPlainArgs =
        GetGatewayHostnameConfigurationPlainArgs(
            gatewayId = gatewayId ?: throw PulumiNullFieldException("gatewayId"),
            hcId = hcId ?: throw PulumiNullFieldException("hcId"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/inputs/GetGatewayHostnameConfigurationPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin.inputs

import com.pulumi.azurenative.apimanagement.inputs.GetGatewayHostnameConfigurationPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property gatewayId Gateway entity identifier. Must be unique in the current API Management service instance. Must not have value 'managed'
 * @property hcId Gateway hostname configuration identifier. Must be unique in the scope of parent Gateway entity.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property serviceName The name of the API Management service.
 */
public data class GetGatewayHostnameConfigurationPlainArgs(
    public val gatewayId: String,
    public val hcId: String,
    public val resourceGroupName: String,
    public val serviceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.apimanagement.inputs.GetGatewayHostnameConfigurationPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.apimanagement.inputs.GetGatewayHostnameConfigurationPlainArgs =
        com.pulumi.azurenative.apimanagement.inputs.GetGatewayHostnameConfigurationPlainArgs.builder()
            .gatewayId(gatewayId.let({ args0 -> args0 }))
            .hcId(hcId.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetGatewayHostnameConfigurationPlainArgs].
 */
@PulumiTagMarker
public class GetGatewayHostnameConfigurationPlainArgsBuilder internal constructor() {
    private var gatewayId: String? = null

    private var hcId: String? = null

    private var resourceGroupName: String? = null

    private var serviceName: String? = null

    /**
     * @param value Gateway entity identifier. Must be unique in the current API Management service instance. Must not have value 'managed'
     */
    @JvmName("nlrqyodypxhnrxsw")
    public suspend fun gatewayId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.gatewayId = mapped
    }

    /**
     * @param value Gateway hostname configuration identifier. Must be unique in the scope of parent Gateway entity.
     */
    @JvmName("edxccmebnmetjtng")
    public suspend fun hcId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.hcId = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("stdfygceleqkngro")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the API Management service.
     */
    @JvmName("ditdoagyqkupsvck")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): GetGatewayHostnameConfigurationPlainArgs =
        GetGatewayHostnameConfigurationPlainArgs(
            gatewayId = gatewayId ?: throw PulumiNullFieldException("gatewayId"),
            hcId = hcId ?: throw PulumiNullFieldException("hcId"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
        )
}
